
Welcome to DSAT's documentation!
================================

DSAT is a framework for handling and connecting distributed writers and producers.

It focuses on using topological indications in order to connect components
and apply some basic ZMQ pattern (push/pull pubsub).

It also provides an integration with circus a way to monitor and handle  your processes. 

It has an explicit focus on debugging

